==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FilterRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { FilterRowDefinitionDescription } from "./FilterRowDefinitionDescription";
/**
 * @hidden
 */
var FilterRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterRowDefinitionDescriptionMetadata, _super);
    function FilterRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterRowDefinitionDescriptionMetadata.b = function (a) {
        if (FilterRowDefinitionDescriptionMetadata.a == null) {
            FilterRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterRowDefinitionDescriptionMetadata.c(FilterRowDefinitionDescriptionMetadata.a);
        }
        if (a.j(FilterRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.y(FilterRowDefinitionDescriptionMetadata.a);
    };
    FilterRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    FilterRowDefinitionDescriptionMetadata.d = function (a) {
        FilterRowDefinitionDescriptionMetadata.b(a);
        a.aa("FilterRowDefinition", function () { return new FilterRowDefinitionDescription(); });
        a.z("FilterRowDefinition", FilterRowDefinitionDescriptionMetadata.a);
    };
    FilterRowDefinitionDescriptionMetadata.$t = markType(FilterRowDefinitionDescriptionMetadata, 'FilterRowDefinitionDescriptionMetadata');
    FilterRowDefinitionDescriptionMetadata.a = null;
    return FilterRowDefinitionDescriptionMetadata;
}(Base));
export { FilterRowDefinitionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/FilterRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { FilterRowDefinitionDescription } from "./FilterRowDefinitionDescription";
/**
 * @hidden
 */
var FilterRowDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterRowDefinitionDescriptionMetadata, _super);
    function FilterRowDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterRowDefinitionDescriptionMetadata.b = function (a) {
        if (FilterRowDefinitionDescriptionMetadata.a == null) {
            FilterRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterRowDefinitionDescriptionMetadata.c(FilterRowDefinitionDescriptionMetadata.a);
        }
        if (a.k(FilterRowDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.aa(FilterRowDefinitionDescriptionMetadata.a);
    };
    FilterRowDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
    };
    FilterRowDefinitionDescriptionMetadata.d = function (a) {
        FilterRowDefinitionDescriptionMetadata.b(a);
        a.ac("FilterRowDefinition", function () { return new FilterRowDefinitionDescription(); });
        a.ab("FilterRowDefinition", FilterRowDefinitionDescriptionMetadata.a);
    };
    FilterRowDefinitionDescriptionMetadata.$t = markType(FilterRowDefinitionDescriptionMetadata, 'FilterRowDefinitionDescriptionMetadata');
    FilterRowDefinitionDescriptionMetadata.a = null;
    return FilterRowDefinitionDescriptionMetadata;
}(Base));
export { FilterRowDefinitionDescriptionMetadata };
